@@ -1,16 +1,17 @@
-use crate::args::{
-    Args, AuthorizeArgs, Command, CountArgs, MoveArgs, NewArgs, QueryArgs, RebaseArgs,
-    SetLockupArgs,
+use {
+    crate::args::{
+        Args, AuthorizeArgs, Command, CountArgs, MoveArgs, NewArgs, QueryArgs, RebaseArgs,
+        SetLockupArgs,
+    },
+    clap::{value_t, value_t_or_exit, App, Arg, ArgMatches, SubCommand},
+    solana_clap_utils::{
+        input_parsers::unix_timestamp_from_rfc3339_datetime,
+        input_validators::{is_amount, is_rfc3339_datetime, is_valid_pubkey, is_valid_signer},
+    },
+    solana_cli_config::CONFIG_FILE,
+    solana_sdk::native_token::sol_to_lamports,
+    std::{ffi::OsString, process::exit},
 };
-use clap::{value_t, value_t_or_exit, App, Arg, ArgMatches, SubCommand};
-use solana_clap_utils::{
-    input_parsers::unix_timestamp_from_rfc3339_datetime,
-    input_validators::{is_amount, is_rfc3339_datetime, is_valid_pubkey, is_valid_signer},
-};
-use solana_cli_config::CONFIG_FILE;
-use solana_sdk::native_token::sol_to_lamports;
-use std::ffi::OsString;
-use std::process::exit;
 
 fn fee_payer_arg<'a, 'b>() -> Arg<'a, 'b> {
     solana_clap_utils::fee_payer::fee_payer_arg().required(true)
